@@ -11,12 +11,12 @@ use pyo3::{Bound, PyAny, PyResult};
 pub fn extract_bytes_ref<'py>(obj: &'py Bound<'py, PyAny>) -> PyResult<&'py [u8]> {
     if let Ok(bytes) = obj.extract::<&[u8]>() {
         Ok(bytes)
-    } else if let Ok(custom) = obj.downcast::<PyBytes>() {
+    } else if let Ok(custom) = obj.cast::<PyBytes>() {
         let a = custom.get();
         Ok(a.as_ref())
     } else {
         Err(pyo3::exceptions::PyTypeError::new_err(
-            "Expected bytes, bytearray, or pyo3-bytes object",
+            "Expected bytes, bytearray, or buffer object",
         ))
     }
 }
@@ -25,14 +25,14 @@ pub fn extract_bytes_ref<'py>(obj: &'py Bound<'py, PyAny>) -> PyResult<&'py [u8]
 pub fn extract_bytes_ref_str<'py>(obj: &'py Bound<'py, PyAny>) -> PyResult<&'py [u8]> {
     if let Ok(bytes) = obj.extract::<&[u8]>() {
         Ok(bytes)
-    } else if let Ok(custom) = obj.downcast::<PyBytes>() {
+    } else if let Ok(custom) = obj.cast::<PyBytes>() {
         let a = custom.get();
         Ok(a.as_ref())
     } else if let Ok(s) = obj.extract::<&str>() {
         Ok(s.as_bytes())
     } else {
         Err(pyo3::exceptions::PyTypeError::new_err(
-            "Expected bytes-like bytes, bytearray, pyo3-bytes object",
+            "Expected bytes, bytearray, buffer object, or string",
         ))
     }
 }
