@@ -555,9 +555,11 @@ impl PyBytes {
     // </python-bytes-methods>
 }
 
-impl<'py> FromPyObject<'py> for PyBytes {
-    fn extract_bound(ob: &Bound<'py, PyAny>) -> PyResult<Self> {
-        let buffer = ob.extract::<PyBytesWrapper>()?;
+impl<'py> FromPyObject<'_, 'py> for PyBytes {
+    type Error = pyo3::PyErr;
+
+    fn extract(obj: Borrowed<'_, 'py, PyAny>) -> Result<Self, Self::Error> {
+        let buffer = obj.extract::<PyBytesWrapper>()?;
         let bytes = Bytes::from_owner(buffer);
         Ok(Self(bytes))
     }
@@ -601,8 +603,9 @@ fn validate_buffer(buf: &PyBuffer<u8>) -> PyResult<()> {
     Ok(())
 }
 
-impl<'py> FromPyObject<'py> for PyBytesWrapper {
-    fn extract_bound(ob: &Bound<'py, PyAny>) -> PyResult<Self> {
+impl<'py> FromPyObject<'_, 'py> for PyBytesWrapper {
+    type Error = pyo3::PyErr;
+    fn extract(ob: pyo3::Borrowed<'_, 'py, pyo3::PyAny>) -> PyResult<Self> {
         if ob.is_instance_of::<pyo3::types::PyBytes>() {
             let buffer = ob.extract::<PyBuffer<u8>>()?;
             Ok(Self(buffer))
