@@ -5,14 +5,16 @@ use pyo3::{exceptions::PyValueError, prelude::*};
 #[derive(Copy, Clone, PartialEq, Eq, Debug, Default)]
 pub struct PyCompression(pub(crate) Compression);
 
-impl FromPyObject<'_> for PyCompression {
-    fn extract_bound(ob: &Bound<'_, PyAny>) -> PyResult<Self> {
-        if let Ok(pyint) = ob.cast::<PyInt>() {
+impl<'py> FromPyObject<'_, 'py> for PyCompression {
+    type Error = pyo3::PyErr;
+
+    fn extract(obj: Borrowed<'_, 'py, PyAny>) -> Result<Self, Self::Error> {
+        if let Ok(pyint) = obj.cast::<PyInt>() {
             let level = pyint.extract::<u32>()?;
             if level < 10 {
                 return Ok(Self(Compression::new(level)));
             }
-        } else if let Ok(pystr) = ob.cast::<PyString>() {
+        } else if let Ok(pystr) = obj.cast::<PyString>() {
             let s = pystr.to_str()?;
             let c = match s {
                 "fast" => Some(Self(Compression::fast())),
