@@ -5,7 +5,7 @@ use pyo3::exceptions::{
     PyFileExistsError, PyFileNotFoundError, PyNotADirectoryError, PyUnicodeDecodeError,
     PyValueError,
 };
-use pyo3::types::{PyBytes, PyTuple, PyType};
+use pyo3::types::{PyBytes, PyTuple};
 use pyo3::{intern, prelude::*};
 use ryo3_bytes::extract_bytes_ref;
 use ryo3_core::types::PathLike;
@@ -18,7 +18,8 @@ const MAIN_SEPARATOR: char = std::path::MAIN_SEPARATOR;
 
 type ArcPathBuf = std::sync::Arc<PathBuf>;
 
-#[pyclass(name = "FsPath", module = "ry.ryo3", frozen)]
+#[pyclass(name = "FsPath", frozen)]
+#[cfg_attr(feature = "ry", pyo3(module = "ry.ryo3"))]
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct PyFsPath {
     pth: ArcPathBuf,
@@ -71,12 +72,13 @@ impl PyFsPath {
         PyTuple::new(py, vec![os_str])
     }
 
-    fn string(&self) -> String {
-        path2str(self.path())
+    #[pyo3(name = "to_string")]
+    fn py_to_string(&self) -> String {
+        self.__str__()
     }
 
     fn __str__(&self) -> String {
-        self.string()
+        path2str(self.path())
     }
 
     fn __repr__(&self) -> String {
@@ -98,7 +100,7 @@ impl PyFsPath {
     }
 
     fn __hash__(&self) -> u64 {
-        let mut hasher = std::collections::hash_map::DefaultHasher::new();
+        let mut hasher = std::hash::DefaultHasher::new();
         self.path().hash(&mut hasher);
         hasher.finish()
     }
@@ -113,7 +115,7 @@ impl PyFsPath {
                     return true;
                 }
                 // if that fails, compare as strings
-                self.string() == path2str(other.as_ref())
+                self.py_to_string() == path2str(other.as_ref())
             }
             CompareOp::Ne => {
                 // start by comparing as paths
@@ -121,7 +123,7 @@ impl PyFsPath {
                     return true;
                 }
                 // if that fails, compare as strings
-                self.string() != path2str(other.as_ref())
+                self.py_to_string() != path2str(other.as_ref())
             }
             CompareOp::Lt => p < o,
             CompareOp::Le => p <= o,
@@ -222,11 +224,16 @@ impl PyFsPath {
         }
     }
 
-    // TODO - implement ad iterator not tuple
     #[getter]
     fn parents<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyTuple>> {
-        let parents: Vec<Self> = self.path().ancestors().map(Self::from).collect();
-        PyTuple::new(py, parents)
+        let parent = self.path().parent();
+        if let Some(par) = parent {
+            let parents: Vec<Self> = par.ancestors().map(Self::from).collect();
+            PyTuple::new(py, parents)
+        } else {
+            // no parents
+            PyTuple::new(py, Vec::<Self>::new())
+        }
     }
 
     #[getter]
@@ -285,7 +292,10 @@ impl PyFsPath {
         let mut p = self.path().to_path_buf();
         while let Some(e) = p.extension() {
             match e.to_str() {
-                Some(e) => suffixes.push(e.to_string()),
+                Some(e) => {
+                    // push with leading dot to match python pathlib
+                    suffixes.push(format!(".{e}"));
+                }
                 None => break,
             }
             p = p.with_extension("");
@@ -304,13 +314,13 @@ impl PyFsPath {
             })
     }
 
-    #[classmethod]
-    fn home(_cls: &Bound<'_, PyType>) -> Option<Self> {
+    #[staticmethod]
+    fn home() -> Option<Self> {
         ryo3_dirs::home().map(Self::from)
     }
 
-    #[classmethod]
-    fn cwd(_cls: &Bound<'_, PyType>) -> PyResult<Self> {
+    #[staticmethod]
+    fn cwd() -> PyResult<Self> {
         std::env::current_dir()
             .map(Self::from)
             .map_err(|e| PyFileNotFoundError::new_err(format!("cwd: {e}")))
@@ -338,13 +348,13 @@ impl PyFsPath {
         Ok(fbytes.into())
     }
 
-    fn read_bytes(&self, py: Python<'_>) -> PyResult<PyObject> {
+    fn read_bytes(&self, py: Python<'_>) -> PyResult<Py<PyAny>> {
         let fbytes = std::fs::read(self.path());
         match fbytes {
             Ok(b) => Ok(PyBytes::new(py, &b).into()),
             Err(e) => {
                 // TODO: figure out cleaner way of doing this
-                let pathstr = self.string();
+                let pathstr = self.py_to_string();
                 let emsg = format!("read_vec_u8 - path: {pathstr} - {e}");
                 Err(PyFileNotFoundError::new_err(emsg))
             }
@@ -353,7 +363,7 @@ impl PyFsPath {
 
     fn read_text(&self, py: Python<'_>) -> PyResult<String> {
         let bvec = std::fs::read(self.path()).map_err(|e| {
-            let pathstr = self.string();
+            let pathstr = self.py_to_string();
             PyFileNotFoundError::new_err(format!("read_text - path: {pathstr} - {e}"))
         })?;
         let r = std::str::from_utf8(&bvec);
@@ -372,7 +382,7 @@ impl PyFsPath {
         match write_res {
             Ok(()) => Ok(b.len()),
             Err(e) => {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 Err(PyNotADirectoryError::new_err(format!(
                     "write_bytes - parent: {fspath} - {e}"
                 )))
@@ -389,7 +399,7 @@ impl PyFsPath {
         match write_result {
             Ok(()) => Ok(()),
             Err(e) => {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 Err(PyNotADirectoryError::new_err(format!(
                     "write_bytes - parent: {fspath} - {e}"
                 )))
@@ -406,17 +416,17 @@ impl PyFsPath {
         if !exist_ok && exists {
             return Err(PyFileExistsError::new_err(format!(
                 "mkdir - parent: {} - directory already exists",
-                self.string()
+                self.py_to_string()
             )));
         }
         if parents {
             std::fs::create_dir_all(path).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("mkdir - parent: {fspath} - {e}"))
             })?;
         } else {
             std::fs::create_dir(path).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("mkdir - parent: {fspath} - {e}"))
             })?;
         }
@@ -426,12 +436,15 @@ impl PyFsPath {
             use std::os::unix::fs::PermissionsExt;
             let mut perms = std::fs::metadata(path)
                 .map_err(|e| {
-                    PyFileNotFoundError::new_err(format!("mkdir - parent: {} - {e}", self.string()))
+                    PyFileNotFoundError::new_err(format!(
+                        "mkdir - parent: {} - {e}",
+                        self.py_to_string()
+                    ))
                 })?
                 .permissions();
             perms.set_mode(mode);
             std::fs::set_permissions(path, perms).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("mkdir - parent: {fspath} - {e}"))
             })?;
         }
@@ -443,23 +456,23 @@ impl PyFsPath {
         if !self.exists()? {
             return Err(PyFileNotFoundError::new_err(format!(
                 "rmdir - parent: {} - directory does not exist",
-                self.string()
+                self.py_to_string()
             )));
         }
         if !self.is_dir() {
             return Err(PyNotADirectoryError::new_err(format!(
                 "rmdir - parent: {} - not a directory",
-                self.string()
+                self.py_to_string()
             )));
         }
         if recursive {
             std::fs::remove_dir_all(self.path()).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("rmdir - parent: {fspath} - {e}"))
             })?;
         } else {
             std::fs::remove_dir(self.path()).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("rmdir - parent: {fspath} - {e}"))
             })?;
         }
@@ -474,14 +487,14 @@ impl PyFsPath {
             }
             return Err(PyFileNotFoundError::new_err(format!(
                 "unlink - parent: {} - file does not exist",
-                self.string()
+                self.py_to_string()
             )));
         }
         if self.is_dir() {
             self.rmdir(recursive)?;
         } else {
             std::fs::remove_file(self.path()).map_err(|e| {
-                let fspath = self.string();
+                let fspath = self.py_to_string();
                 PyNotADirectoryError::new_err(format!("unlink - parent: {fspath} - {e}"))
             })?;
         }
@@ -496,11 +509,11 @@ impl PyFsPath {
         if new_path.exists() {
             return Err(PyFileExistsError::new_err(format!(
                 "rename - parent: {} - destination already exists",
-                self.string()
+                self.py_to_string()
             )));
         }
         std::fs::rename(self.path(), new_path).map_err(|e| {
-            let fspath = self.string();
+            let fspath = self.py_to_string();
             PyNotADirectoryError::new_err(format!("rename - parent: {fspath} - {e}"))
         })?;
         Ok(Self::from(new_path))
@@ -520,7 +533,7 @@ impl PyFsPath {
             }
         }
         std::fs::rename(self.path(), new_path).map_err(|e| {
-            let fspath = self.string();
+            let fspath = self.py_to_string();
             PyNotADirectoryError::new_err(format!("replace - parent: {fspath} - {e}"))
         })?;
         Ok(Self::from(new_path))
@@ -595,9 +608,8 @@ impl PyFsPath {
     //  - Path.to_path_buf
     //  - Path.as_mut_os_str
     //  - Path.as_os_str
-    fn ancestors<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyTuple>> {
-        let parents: Vec<Self> = self.path().ancestors().map(Self::from).collect();
-        PyTuple::new(py, parents)
+    fn ancestors(&self) -> PyFsPathAncestors {
+        PyFsPathAncestors::new(self.path())
     }
 
     fn canonicalize(&self) -> PyResult<Self> {
@@ -680,18 +692,17 @@ impl PyFsPath {
         Self::from(self.path().join(p))
     }
 
-    fn metadata(&self) -> PyResult<ryo3_std::PyMetadata> {
+    fn metadata(&self) -> PyResult<ryo3_std::fs::PyMetadata> {
         self.path()
             .metadata()
-            .map(ryo3_std::PyMetadata::from)
+            .map(ryo3_std::fs::PyMetadata::from)
             .map_err(|e| PyFileNotFoundError::new_err(format!("metadata: {e}")))
     }
 
     fn read_dir(&self) -> PyResult<PyFsPathReadDir> {
-        let rd = std::fs::read_dir(self.path())
+        std::fs::read_dir(self.path())
             .map(PyFsPathReadDir::from)
-            .map_err(|e| PyFileNotFoundError::new_err(format!("iterdir: {e}")))?;
-        Ok(rd)
+            .map_err(|e| PyFileNotFoundError::new_err(format!("iterdir: {e}")))
     }
 
     fn read_link(&self) -> PyResult<Self> {
@@ -712,10 +723,10 @@ impl PyFsPath {
             .map_err(|e| PyValueError::new_err(format!("strip_prefix: {e}")))
     }
 
-    fn symlink_metadata(&self) -> PyResult<ryo3_std::PyMetadata> {
+    fn symlink_metadata(&self) -> PyResult<ryo3_std::fs::PyMetadata> {
         self.path()
             .metadata()
-            .map(ryo3_std::PyMetadata::from)
+            .map(ryo3_std::fs::PyMetadata::from)
             .map_err(|e| PyFileNotFoundError::new_err(format!("metadata: {e}")))
     }
 
@@ -812,7 +823,8 @@ where
     }
 }
 
-#[pyclass(name = "FsPathReadDir", module = "ry.ryo3", frozen)]
+#[pyclass(name = "FsPathReadDir", frozen)]
+#[cfg_attr(feature = "ry", pyo3(module = "ry.ryo3"))]
 pub struct PyFsPathReadDir {
     iter: Mutex<std::fs::ReadDir>,
 }
@@ -824,7 +836,8 @@ impl PyFsPathReadDir {
     }
 
     fn __next__(&self) -> Option<PyFsPath> {
-        match self.iter.lock().next() {
+        let value = self.iter.lock().next();
+        match value {
             Some(Ok(entry)) => Some(PyFsPath::from(entry.path())),
             _ => None,
         }
@@ -860,3 +873,67 @@ impl From<std::fs::ReadDir> for PyFsPathReadDir {
         Self { iter: iter.into() }
     }
 }
+
+#[pyclass(name = "FsPathAncestors", frozen)]
+#[cfg_attr(feature = "ry", pyo3(module = "ry.ryo3"))]
+pub struct PyFsPathAncestors {
+    path: ArcPathBuf,
+    current: Mutex<Option<ArcPathBuf>>,
+}
+
+impl PyFsPathAncestors {
+    pub fn new<P: AsRef<Path>>(p: P) -> Self {
+        Self {
+            path: ArcPathBuf::new(p.as_ref().to_path_buf()),
+            current: Mutex::new(Some(ArcPathBuf::new(p.as_ref().to_path_buf()))),
+        }
+    }
+}
+
+#[pymethods]
+impl PyFsPathAncestors {
+    fn __repr__(&self) -> String {
+        format!("{self}")
+    }
+
+    fn __iter__(slf: PyRef<'_, Self>) -> PyRef<'_, Self> {
+        slf
+    }
+
+    fn __next__(&self) -> Option<PyFsPath> {
+        let mut current = self.current.lock();
+        let taken = current.take().map(|p| PyFsPath::from(p.as_ref()));
+        if let Some(ref p) = taken {
+            let next = p.path().parent().map(|p| ArcPathBuf::new(p.to_path_buf()));
+            *current = next;
+        }
+        taken
+    }
+
+    fn collect(&self) -> Vec<PyFsPath> {
+        let mut paths = vec![];
+        while let Some(path) = self.__next__() {
+            paths.push(path);
+        }
+        paths
+    }
+
+    #[pyo3(signature = (n = 1))]
+    fn take(&self, n: usize) -> Vec<PyFsPath> {
+        let mut paths = vec![];
+        for _ in 0..n {
+            if let Some(path) = self.__next__() {
+                paths.push(path);
+            } else {
+                break;
+            }
+        }
+        paths
+    }
+}
+
+impl std::fmt::Display for PyFsPathAncestors {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "FsPathAncestors<{}>", self.path.display())
+    }
+}
