@@ -2,9 +2,9 @@ use crate::jiff_types::JiffTzOffsetConflict;
 use pyo3::prelude::*;
 
 const JIFF_TZ_OFFSET_CONFLICTS: &str = "'always-offset', 'always-timezone', 'prefer-offset', 'reject' (case-insensitive; underscores and hyphens are interchangeable)";
-impl FromPyObject<'_> for JiffTzOffsetConflict {
-    fn extract_bound(ob: &Bound<'_, PyAny>) -> PyResult<Self> {
-        // downcast to string...
+impl<'py> FromPyObject<'_, 'py> for JiffTzOffsetConflict {
+    type Error = PyErr;
+    fn extract(ob: Borrowed<'_, 'py, PyAny>) -> PyResult<Self> {
         if let Ok(s) = ob.extract::<&str>() {
             match s {
                 "always_offset" | "always-offset" => {
