@@ -1,7 +1,6 @@
-use crate::deprecations::deprecation_warning_intz;
+use crate::difference::{DateTimeDifferenceArg, RyDateTimeDifference};
 use crate::errors::{map_py_overflow_err, map_py_value_err};
 use crate::isoformat::{ISOFORMAT_PRINTER, ISOFORMAT_PRINTER_NO_MICROS};
-use crate::ry_datetime_difference::{DateTimeDifferenceArg, RyDateTimeDifference};
 use crate::ry_iso_week_date::RyISOWeekDate;
 use crate::ry_signed_duration::RySignedDuration;
 use crate::ry_span::RySpan;
@@ -10,13 +9,18 @@ use crate::ry_timezone::RyTimeZone;
 use crate::ry_zoned::RyZoned;
 use crate::series::RyDateTimeSeries;
 use crate::spanish::Spanish;
-use crate::{JiffEraYear, JiffRoundMode, JiffUnit, JiffWeekday, RyDate, RyDateTimeRound};
+use crate::{
+    JiffDateTime, JiffEra, JiffEraYear, JiffRoundMode, JiffUnit, JiffWeekday, RyDate,
+    RyDateTimeRound, RyTimestamp,
+};
 use jiff::Zoned;
 use jiff::civil::{Date, DateTime, DateTimeRound, Time, Weekday};
+use jiff::tz::TimeZone;
+use pyo3::IntoPyObjectExt;
 use pyo3::basic::CompareOp;
 use pyo3::prelude::*;
-use pyo3::types::{PyDict, PyTuple, PyType};
-use pyo3::{IntoPyObjectExt, intern};
+use pyo3::types::{PyDict, PyTuple};
+use ryo3_macro_rules::{any_repr, py_type_err, py_type_error};
 use std::fmt::Display;
 use std::hash::{DefaultHasher, Hash, Hasher};
 use std::ops::Sub;
@@ -24,8 +28,9 @@ use std::str::FromStr;
 
 #[cfg_attr(feature = "serde", derive(serde::Serialize))]
 #[cfg_attr(feature = "serde", serde(transparent))]
-#[derive(Debug, Clone, PartialEq, PartialOrd)]
-#[pyclass(name = "DateTime", module = "ry.ryo3", frozen)]
+#[derive(Debug, Clone, Copy, PartialEq, PartialOrd)]
+#[pyclass(name = "DateTime", frozen)]
+#[cfg_attr(feature = "ry", pyo3(module = "ry.ryo3"))]
 pub struct RyDateTime(pub(crate) DateTime);
 
 impl From<DateTime> for RyDateTime {
@@ -37,7 +42,7 @@ impl From<DateTime> for RyDateTime {
 #[pymethods]
 impl RyDateTime {
     #[new]
-    #[pyo3(signature = ( year, month, day, hour=0, minute=0, second=0, subsec_nanosecond=0))]
+    #[pyo3(signature = (year, month, day, hour=0, minute=0, second=0, subsec_nanosecond=0))]
     pub(crate) fn py_new(
         year: i16,
         month: i8,
@@ -57,7 +62,7 @@ impl RyDateTime {
             subsec_nanosecond.unwrap_or(0),
         )
         .map(Self::from)
-        .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+        .map_err(map_py_value_err)
     }
 
     fn __getnewargs__<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyTuple>> {
@@ -86,21 +91,41 @@ impl RyDateTime {
     fn MAX() -> Self {
         Self(DateTime::MAX)
     }
+
     #[expect(non_snake_case)]
     #[classattr]
     fn ZERO() -> Self {
         Self(DateTime::ZERO)
     }
 
-    #[classmethod]
-    fn now(_cls: &Bound<'_, PyType>) -> Self {
+    #[staticmethod]
+    fn now() -> Self {
         Self::from(DateTime::from(Zoned::now()))
     }
-    #[classmethod]
-    fn parse(_cls: &Bound<'_, PyType>, s: &str) -> PyResult<Self> {
-        DateTime::from_str(s)
-            .map(Self::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+
+    #[staticmethod]
+    fn today() -> Self {
+        Self::from(DateTime::from(Zoned::now()))
+    }
+
+    #[staticmethod]
+    fn from_str(s: &str) -> PyResult<Self> {
+        // if ends with 'Z', parse via timezone...
+        if s.ends_with('Z') {
+            jiff::Timestamp::from_str(s)
+                .map(|ts| ts.to_zoned(TimeZone::UTC).datetime())
+                .map(Self::from)
+                .map_err(map_py_value_err)
+        } else {
+            DateTime::from_str(s)
+                .map(Self::from)
+                .map_err(map_py_value_err)
+        }
+    }
+
+    #[staticmethod]
+    fn parse(s: &str) -> PyResult<Self> {
+        Self::from_str(s)
     }
 
     fn __richcmp__(&self, other: &Self, op: CompareOp) -> bool {
@@ -165,24 +190,16 @@ impl RyDateTime {
     }
 
     fn __str__(&self) -> String {
-        self.to_string()
+        self.0.to_string()
     }
 
-    fn string(&self) -> String {
-        self.to_string()
+    #[pyo3(name = "to_string")]
+    fn py_to_string(&self) -> String {
+        self.__str__()
     }
 
     fn __repr__(&self) -> String {
-        format!(
-            "DateTime(year={}, month={}, day={}, hour={}, minute={}, second={}, subsec_nanosecond={})",
-            self.year(),
-            self.month(),
-            self.day(),
-            self.hour(),
-            self.minute(),
-            self.second(),
-            self.subsec_nanosecond()
-        )
+        format!("{self}")
     }
 
     fn __hash__(&self) -> u64 {
@@ -204,7 +221,7 @@ impl RyDateTime {
         py: Python<'py>,
         other: &Bound<'py, PyAny>,
     ) -> PyResult<Bound<'py, PyAny>> {
-        if let Ok(ob) = other.downcast::<Self>() {
+        if let Ok(ob) = other.cast::<Self>() {
             let span = self.0.sub(ob.get().0);
             let obj = RySpan::from(span).into_pyobject(py).map(Bound::into_any)?;
             Ok(obj)
@@ -215,15 +232,11 @@ impl RyDateTime {
         }
     }
 
-    fn checked_add<'py>(&self, other: &'py Bound<'py, PyAny>) -> PyResult<Self> {
+    fn add<'py>(&self, other: &'py Bound<'py, PyAny>) -> PyResult<Self> {
         self.__add__(other)
     }
 
-    fn checked_sub<'py>(
-        &self,
-        py: Python<'py>,
-        other: &Bound<'py, PyAny>,
-    ) -> PyResult<Bound<'py, PyAny>> {
+    fn sub<'py>(&self, py: Python<'py>, other: &Bound<'py, PyAny>) -> PyResult<Bound<'py, PyAny>> {
         self.__sub__(py, other)
     }
 
@@ -237,11 +250,11 @@ impl RyDateTime {
         Ok(Self::from(self.0.saturating_sub(spanish)))
     }
 
-    fn time(&self) -> RyTime {
+    pub(crate) fn time(&self) -> RyTime {
         RyTime::from(self.0.time())
     }
 
-    fn date(&self) -> RyDate {
+    pub(crate) fn date(&self) -> RyDate {
         RyDate::from(self.0.date())
     }
 
@@ -249,11 +262,16 @@ impl RyDateTime {
         self.0
             .in_tz(tz)
             .map(RyZoned::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+            .map_err(map_py_value_err)
     }
 
-    fn intz(&self, py: Python, tz: &str) -> PyResult<RyZoned> {
-        deprecation_warning_intz(py)?;
+    #[pyo3(
+        warn(
+            message = "`intz` is deprecated, use `in_tz` instead",
+            category = pyo3::exceptions::PyDeprecationWarning
+        )
+    )]
+    fn intz(&self, tz: &str) -> PyResult<RyZoned> {
         self.in_tz(tz)
     }
 
@@ -270,38 +288,44 @@ impl RyDateTime {
         RyISOWeekDate::from(self.0.iso_week_date())
     }
 
-    fn to_zoned(&self, tz: RyTimeZone) -> PyResult<RyZoned> {
+    #[expect(clippy::wrong_self_convention)]
+    fn to_zoned(&self, tz: &RyTimeZone) -> PyResult<RyZoned> {
         self.0
             .to_zoned(tz.into())
             .map(RyZoned::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+            .map_err(map_py_value_err)
     }
 
     fn first_of_month(&self) -> Self {
         Self::from(self.0.first_of_month())
     }
+
     fn last_of_month(&self) -> Self {
         Self::from(self.0.last_of_month())
     }
 
+    #[expect(clippy::wrong_self_convention)]
     fn to_py(&self) -> DateTime {
         self.to_pydatetime()
     }
 
+    #[expect(clippy::wrong_self_convention)]
     fn to_pydatetime(&self) -> DateTime {
         self.0
     }
 
+    #[expect(clippy::wrong_self_convention)]
     fn to_pydate(&self) -> Date {
         self.0.date()
     }
 
+    #[expect(clippy::wrong_self_convention)]
     fn to_pytime(&self) -> Time {
         self.0.time()
     }
 
-    #[classmethod]
-    fn from_pydatetime(_cls: &Bound<'_, PyType>, d: DateTime) -> Self {
+    #[staticmethod]
+    fn from_pydatetime(d: DateTime) -> Self {
         Self::from(d)
     }
 
@@ -311,18 +335,126 @@ impl RyDateTime {
         Ok(RyDateTimeSeries::from(s))
     }
 
-    fn asdict<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyDict>> {
+    #[expect(clippy::wrong_self_convention)]
+    fn to_dict<'py>(&self, py: Python<'py>) -> PyResult<Bound<'py, PyDict>> {
+        use crate::interns;
         let dict = PyDict::new(py);
-        dict.set_item(intern!(py, "year"), self.0.year())?;
-        dict.set_item(intern!(py, "month"), self.0.month())?;
-        dict.set_item(intern!(py, "day"), self.0.day())?;
-        dict.set_item(intern!(py, "hour"), self.0.hour())?;
-        dict.set_item(intern!(py, "minute"), self.0.minute())?;
-        dict.set_item(intern!(py, "second"), self.0.second())?;
-        dict.set_item(intern!(py, "nanosecond"), self.0.subsec_nanosecond())?;
+        dict.set_item(interns::year(py), self.0.year())?;
+        dict.set_item(interns::month(py), self.0.month())?;
+        dict.set_item(interns::day(py), self.0.day())?;
+        dict.set_item(interns::hour(py), self.0.hour())?;
+        dict.set_item(interns::minute(py), self.0.minute())?;
+        dict.set_item(interns::second(py), self.0.second())?;
+        dict.set_item(interns::nanosecond(py), self.0.subsec_nanosecond())?;
         Ok(dict)
     }
 
+    #[pyo3(
+        signature = (
+            obj=None,
+            *,
+            date=None,
+            time=None,
+            year=None,
+            era_year=None,
+            month=None,
+            day=None,
+            day_of_year=None,
+            day_of_year_no_leap=None,
+            hour=None,
+            minute=None,
+            second=None,
+            millisecond=None,
+            microsecond=None,
+            nanosecond=None,
+            subsec_nanosecond=None,
+        )
+    )]
+    #[expect(clippy::too_many_arguments)]
+    fn replace(
+        &self,
+        obj: Option<Bound<'_, PyAny>>,
+        date: Option<RyDate>,
+        time: Option<RyTime>,
+        year: Option<i16>,
+        era_year: Option<(i16, JiffEra)>,
+        month: Option<i8>,
+        day: Option<i8>,
+        day_of_year: Option<i16>,
+        day_of_year_no_leap: Option<i16>,
+        hour: Option<i8>,
+        minute: Option<i8>,
+        second: Option<i8>,
+        millisecond: Option<i16>,
+        microsecond: Option<i16>,
+        nanosecond: Option<i16>,
+        subsec_nanosecond: Option<i32>,
+    ) -> PyResult<Self> {
+        // start the builder
+        let mut builder = self.0.with();
+        if let Some(obj) = obj {
+            // if obj is a Zoned, use it as the base
+            if let Ok(zoned) = obj.cast::<RyDate>() {
+                // if obj is a Zoned, use it as the base
+                let date = zoned.extract::<RyDate>()?;
+                builder = builder.date(date.0);
+            } else if let Ok(time) = obj.cast::<RyTime>() {
+                // if obj is a Time, use it as the base
+                let time = time.extract::<RyTime>()?;
+                builder = builder.time(time.0);
+            } else {
+                return Err(py_type_error!("obj must be a Date or Time; given: {obj}"));
+            }
+        }
+        // only override if the Option is Some
+        if let Some(date) = date {
+            builder = builder.date(date.0);
+        }
+        if let Some(time) = time {
+            builder = builder.time(time.0);
+        }
+        if let Some(y) = year {
+            builder = builder.year(y);
+        }
+        if let Some(ey) = era_year {
+            builder = builder.era_year(ey.0, (ey.1).0);
+        }
+        if let Some(m) = month {
+            builder = builder.month(m);
+        }
+        if let Some(d) = day {
+            builder = builder.day(d);
+        }
+        if let Some(doy) = day_of_year {
+            builder = builder.day_of_year(doy);
+        }
+        if let Some(doy) = day_of_year_no_leap {
+            builder = builder.day_of_year_no_leap(doy);
+        }
+        if let Some(h) = hour {
+            builder = builder.hour(h);
+        }
+        if let Some(min) = minute {
+            builder = builder.minute(min);
+        }
+        if let Some(sec) = second {
+            builder = builder.second(sec);
+        }
+        if let Some(us) = microsecond {
+            builder = builder.microsecond(us);
+        }
+        if let Some(ms) = millisecond {
+            builder = builder.millisecond(ms);
+        }
+        if let Some(ns) = nanosecond {
+            builder = builder.nanosecond(ns);
+        }
+        if let Some(subns) = subsec_nanosecond {
+            builder = builder.subsec_nanosecond(subns);
+        }
+        builder.build().map(Self::from).map_err(map_py_value_err)
+    }
+
     #[pyo3(
        signature = (smallest=None, *, mode = None, increment = None),
     )]
@@ -345,14 +477,11 @@ impl RyDateTime {
         self.0
             .round(dt_round)
             .map(Self::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+            .map_err(map_py_value_err)
     }
 
     fn _round(&self, dt_round: &RyDateTimeRound) -> PyResult<Self> {
-        self.0
-            .round(dt_round.round)
-            .map(Self::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+        dt_round.round(self)
     }
 
     fn day_of_year(&self) -> i16 {
@@ -379,7 +508,7 @@ impl RyDateTime {
         self.0.duration_until(dt.0).into()
     }
 
-    /// Returns the end of the day DateTime
+    /// Returns the end of the day `DateTime`
     fn end_of_day(&self) -> Self {
         Self::from(self.0.end_of_day())
     }
@@ -395,28 +524,39 @@ impl RyDateTime {
         Self::from(self.0.first_of_year())
     }
 
-    #[classmethod]
-    fn from_parts(_cls: &Bound<'_, PyType>, date: &RyDate, time: &RyTime) -> Self {
+    #[staticmethod]
+    fn from_parts(date: &RyDate, time: &RyTime) -> Self {
         Self::from(DateTime::from_parts(date.0, time.0))
     }
+
     fn in_leap_year(&self) -> bool {
         self.0.in_leap_year()
     }
+
     fn last_of_year(&self) -> Self {
         Self::from(self.0.last_of_year())
     }
+
     fn start_of_day(&self) -> Self {
         Self::from(self.0.start_of_day())
     }
-    fn strftime(&self, format: &str) -> String {
-        self.0.strftime(format).to_string()
+
+    fn __format__(&self, fmt: &str) -> PyResult<String> {
+        self.strftime(fmt)
     }
 
-    #[classmethod]
-    fn strptime(_cls: &Bound<'_, PyType>, s: &str, format: &str) -> PyResult<Self> {
-        DateTime::strptime(s, format)
+    #[pyo3(signature = (fmt))]
+    fn strftime(&self, fmt: &str) -> PyResult<String> {
+        let bdt: jiff::fmt::strtime::BrokenDownTime = self.0.into();
+        bdt.to_string(fmt).map_err(map_py_value_err)
+    }
+
+    #[staticmethod]
+    #[pyo3(signature = (s, /, fmt))]
+    fn strptime(s: &str, fmt: &str) -> PyResult<Self> {
+        DateTime::strptime(fmt, s)
             .map(Self::from)
-            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(format!("{e}")))
+            .map_err(map_py_value_err)
     }
 
     #[pyo3(
@@ -436,6 +576,7 @@ impl RyDateTime {
             .map(RySpan::from)
             .map_err(map_py_value_err)
     }
+
     #[pyo3(
        signature = (datetime, *, smallest=None, largest = None, mode = None, increment = None),
     )]
@@ -456,14 +597,14 @@ impl RyDateTime {
 
     fn _since(&self, other: &RyDateTimeDifference) -> PyResult<RySpan> {
         self.0
-            .since(other.0)
+            .since(other.diff)
             .map(RySpan::from)
             .map_err(map_py_value_err)
     }
 
     fn _until(&self, other: &RyDateTimeDifference) -> PyResult<RySpan> {
         self.0
-            .until(other.0)
+            .until(other.diff)
             .map(RySpan::from)
             .map_err(map_py_value_err)
     }
@@ -502,10 +643,67 @@ impl RyDateTime {
             Weekday::Sunday => 7,
         }
     }
+
+    #[staticmethod]
+    fn from_any<'py>(value: &Bound<'py, PyAny>) -> PyResult<Bound<'py, PyAny>> {
+        let py = value.py();
+        if let Ok(pystr) = value.cast::<pyo3::types::PyString>() {
+            let s = pystr.extract::<&str>()?;
+            Self::from_str(s).map(|dt| dt.into_bound_py_any(py).map(Bound::into_any))?
+        } else if let Ok(pybytes) = value.cast::<pyo3::types::PyBytes>() {
+            let s = String::from_utf8_lossy(pybytes.as_bytes());
+            Self::from_str(&s).map(|dt| dt.into_bound_py_any(py).map(Bound::into_any))?
+        } else if value.is_exact_instance_of::<Self>() {
+            value.into_bound_py_any(py)
+        } else if let Ok(d) = value.cast_exact::<RyZoned>() {
+            let dt = d.get().time();
+            dt.into_bound_py_any(py)
+        } else if let Ok(d) = value.cast_exact::<RyTimestamp>() {
+            let dt = d.get().time();
+            dt.into_bound_py_any(py)
+        } else if let Ok(d) = value.extract::<JiffDateTime>() {
+            Self::from(d.0).into_bound_py_any(py)
+        } else {
+            let valtype = any_repr!(value);
+            py_type_err!("DateTime conversion error: {valtype}",)
+        }
+    }
+    // ========================================================================
+    // PYDANTIC
+    // ========================================================================
+    #[cfg(feature = "pydantic")]
+    #[staticmethod]
+    fn _pydantic_validate<'py>(
+        value: &Bound<'py, PyAny>,
+        _handler: &Bound<'py, PyAny>,
+    ) -> PyResult<Bound<'py, PyAny>> {
+        Self::from_any(value).map_err(map_py_value_err)
+    }
+
+    #[cfg(feature = "pydantic")]
+    #[classmethod]
+    fn __get_pydantic_core_schema__<'py>(
+        cls: &Bound<'py, ::pyo3::types::PyType>,
+        source: &Bound<'py, PyAny>,
+        handler: &Bound<'py, PyAny>,
+    ) -> PyResult<Bound<'py, PyAny>> {
+        use ryo3_pydantic::GetPydanticCoreSchemaCls;
+        Self::get_pydantic_core_schema(cls, source, handler)
+    }
 }
 
 impl Display for RyDateTime {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        self.0.fmt(f)
+        write!(
+            f,
+            "DateTime(year={}, month={}, day={}, hour={}, minute={}, second={}, subsec_nanosecond={})",
+            self.year(),
+            self.month(),
+            self.day(),
+            self.hour(),
+            self.minute(),
+            self.second(),
+            self.subsec_nanosecond()
+        )
     }
 }
