@@ -1,7 +1,7 @@
 #![doc = include_str!("../README.md")]
+mod cert;
 mod client;
 mod cookie;
-mod default_client;
 mod errors;
 mod fetch;
 mod form_data;
@@ -9,6 +9,7 @@ mod pyo3_json_bytes;
 mod response_head;
 mod response_parking_lot;
 mod response_stream;
+mod tls_version;
 mod user_agent;
 
 pub use client::RyHttpClient;
@@ -18,8 +19,11 @@ use pyo3::prelude::*;
 pub use response_parking_lot::RyResponse;
 pub use response_stream::RyResponseStream;
 
+use crate::cert::PyCertificate;
+
 pub fn pymod_add(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<PyCookie>()?;
+    m.add_class::<PyCertificate>()?;
     m.add_class::<RyHttpClient>()?;
     m.add_class::<RyResponse>()?;
     m.add_class::<RyReqwestError>()?;
