@@ -1,9 +1,7 @@
 #![doc = include_str!("../README.md")]
 mod py_uuid;
 use crate::py_uuid::{RESERVED_FUTURE, RESERVED_MICROSOFT, RESERVED_NCS, RFC_4122};
-pub use py_uuid::{
-    CPythonUuid, PyUuid, getnode, uuid1, uuid2, uuid3, uuid4, uuid5, uuid6, uuid7, uuid8,
-};
+pub use py_uuid::{CPythonUuid, PyUuid, getnode, uuid1, uuid3, uuid4, uuid5, uuid6, uuid7, uuid8};
 use pyo3::prelude::PyModule;
 use pyo3::prelude::*;
 pub use uuid;
@@ -20,7 +18,6 @@ pub fn pymod_add(m: &Bound<'_, PyModule>) -> PyResult<()> {
     m.add_class::<PyUuid>()?;
     m.add_function(wrap_pyfunction!(getnode, m)?)?;
     m.add_function(wrap_pyfunction!(uuid1, m)?)?;
-    m.add_function(wrap_pyfunction!(uuid2, m)?)?;
     m.add_function(wrap_pyfunction!(uuid3, m)?)?;
     m.add_function(wrap_pyfunction!(uuid4, m)?)?;
     m.add_function(wrap_pyfunction!(uuid4, m)?)?;
