@@ -5,7 +5,7 @@ use pyo3::sync::PyOnceLock;
 use pyo3::types::PyTuple;
 use pyo3::{IntoPyObjectExt, intern};
 use ryo3_bytes::PyBytes;
-use ryo3_macro_rules::{any_repr, py_type_err, py_value_error, pytodo};
+use ryo3_macro_rules::{any_repr, py_type_err, py_value_err, py_value_error, pytodo};
 use std::hash::{DefaultHasher, Hash, Hasher};
 use std::sync::OnceLock;
 
@@ -62,9 +62,7 @@ fn get_version(uuid: u8) -> PyResult<uuid::Version> {
         6 => Ok(uuid::Version::SortMac),
         7 => Ok(uuid::Version::SortRand),
         8 => Ok(uuid::Version::Custom),
-        _ => Err(PyValueError::new_err(format!(
-            "Invalid UUID version: {uuid}. Must be between 1 and 8."
-        ))),
+        _ => py_value_err!("Invalid UUID version: {uuid}. Must be between 1 and 8."),
     }
 }
 
@@ -340,10 +338,32 @@ impl PyUuid {
     }
 
     #[getter]
+    /// The 60-bit timestamp as a count of 100-nanosecond intervals since
+    /// Gregorian epoch (1582-10-15 00:00:00) for versions 1 and 6, or the
+    /// 48-bit timestamp in milliseconds since Unix epoch (1970-01-01 00:00:00)
+    /// for version 7.
     fn time(&self) -> u64 {
-        let high = u64::from(self.time_hi_version()) & 0x0fff;
-        let mid = u64::from(self.time_mid());
-        high.wrapping_shl(48) | mid.wrapping_shl(32) | u64::from(self.time_low())
+        self.py_time()
+        // let version_rfc = (
+        //     self.version(),
+        //     matches!(self.0.get_variant(), uuid::Variant::RFC4122),
+        // );
+        // match version_rfc {
+        //     (6, true) => {
+        //         let high32 = (u64::from(self.time_low())) << 28;
+        //         let mid16 = (u64::from(self.time_mid())) << 12;
+        //         let low12 = u64::from(self.time_hi_version()) & 0x0fff;
+        //         high32 | mid16 | low12
+        //     }
+        //     (7, true) => (self.0.as_u128() >> 80) as u64,
+        //     // should be 1 and/or any other versions but idk if it is actually
+        //     // implemented?
+        //     _ => {
+        //         let high = u64::from(self.time_hi_version()) & 0x0fff;
+        //         let mid = u64::from(self.time_mid());
+        //         high.wrapping_shl(48) | mid.wrapping_shl(32) | u64::from(self.time_low())
+        //     }
+        // }
     }
 
     #[getter]
@@ -409,6 +429,7 @@ impl PyUuid {
         value: &Bound<'py, PyAny>,
         _handler: &Bound<'py, PyAny>,
     ) -> PyResult<Bound<'py, PyAny>> {
+        use ryo3_macro_rules::py_value_error;
         Self::from_any(value).map_err(|e| py_value_error!("UUID validation error: {e}"))
     }
 
@@ -424,6 +445,40 @@ impl PyUuid {
     }
 }
 
+#[cfg(not(Py_3_14))]
+impl PyUuid {
+    fn py_time(&self) -> u64 {
+        let high = u64::from(self.time_hi_version()) & 0x0fff;
+        let mid = u64::from(self.time_mid());
+        high.wrapping_shl(48) | mid.wrapping_shl(32) | u64::from(self.time_low())
+    }
+}
+
+#[cfg(Py_3_14)]
+impl PyUuid {
+    fn py_time(&self) -> u64 {
+        let version_rfc = (
+            self.version(),
+            matches!(self.0.get_variant(), uuid::Variant::RFC4122),
+        );
+        match version_rfc {
+            (6, true) => {
+                (u64::from(self.time_low()) << 28)
+                    | (u64::from(self.time_mid()) << 12)
+                    | (u64::from(self.time_hi_version()) & 0x0fff)
+            }
+            (7, true) => (self.0.as_u128() >> 80) as u64,
+            // should be 1 and/or any other versions but idk if it is actually
+            // implemented?
+            _ => {
+                let high = u64::from(self.time_hi_version()) & 0x0fff;
+                let mid = u64::from(self.time_mid());
+                high.wrapping_shl(48) | mid.wrapping_shl(32) | u64::from(self.time_low())
+            }
+        }
+    }
+}
+
 #[pyfunction(name = "getnode")]
 pub fn getnode(py: Python<'_>) -> PyResult<u64> {
     if let Some(v) = NODE_CACHE.get() {
@@ -431,7 +486,7 @@ pub fn getnode(py: Python<'_>) -> PyResult<u64> {
     }
     let node_py: u64 = py.import("uuid")?.getattr("getnode")?.call0()?.extract()?;
     if node_py > 0xFF_FFFF_FFFF_FFFF {
-        Err(PyValueError::new_err("uuid.getnode() returned >48 bits"))
+        py_value_err!("uuid.getnode() returned >48 bits")
     } else {
         let _ = NODE_CACHE.set(node_py);
         Ok(node_py)
@@ -449,11 +504,6 @@ pub fn uuid1(node: Option<u64>, clock_seq: Option<u16>) -> PyResult<PyUuid> {
     pytodo!("UUID1 is not implemented yet")
 }
 
-#[pyfunction]
-pub fn uuid2() -> PyResult<PyUuid> {
-    pytodo!("UUID2 is not implemented yet")
-}
-
 #[pyfunction]
 pub fn uuid3() -> PyResult<PyUuid> {
     pytodo!("UUID3 is not implemented yet")
@@ -475,16 +525,52 @@ pub fn uuid6() -> PyResult<PyUuid> {
 }
 
 #[pyfunction]
-pub fn uuid7() -> PyResult<PyUuid> {
-    pytodo!("UUID7 is not implemented yet")
+#[must_use]
+pub fn uuid7() -> PyUuid {
+    PyUuid::from(uuid::Uuid::now_v7())
 }
 
-#[pyfunction]
-#[expect(clippy::needless_pass_by_value)]
-pub fn uuid8(b: PyBytes) -> PyResult<PyUuid> {
-    uuid::Bytes::try_from(b.as_slice())
-        .map(|b| PyUuid::from(uuid::Uuid::new_v8(b)))
-        .map_err(|_| py_value_error!("UUID8 must be 16 bytes long"))
+#[pyfunction(
+    signature = (a = None, b = None, c = None, buf = None),
+)]
+pub fn uuid8(
+    a: Option<u64>,
+    b: Option<u16>,
+    c: Option<u64>,
+    buf: Option<PyBytes>,
+) -> PyResult<PyUuid> {
+    use rand::RngCore;
+
+    if let Some(bts) = buf {
+        match (a, b, c) {
+            (None, None, None) => {}
+            _ => {
+                return py_value_err!("uuid8(): pass either bytes=... or a/b/c, not both",);
+            }
+        }
+        // extract the bytes as [u8; 16]
+        let slice: &[u8; 16] = bts
+            .as_slice()
+            .try_into()
+            .map_err(|_| py_value_error!("uuid8(bytes=...): bytes must be exactly 16 bytes",))?;
+        return Ok(PyUuid::from(uuid::Uuid::new_v8(*slice)));
+    }
+
+    let mut rng = rand::rng();
+
+    let mut ubuf: [u8; 16] = [0; 16];
+    let a48: u64 = a.unwrap_or_else(|| rng.next_u64()) & ((1u64 << 48) - 1);
+    let b12: u16 = b.unwrap_or_else(|| (rng.next_u32() & 0xFFFF) as u16) & 0x0FFF;
+    let c62: u64 = c.unwrap_or_else(|| rng.next_u64()) & ((1u64 << 62) - 1);
+
+    // least significant 48 bits of a
+    ubuf[0..6].copy_from_slice(&a48.to_be_bytes()[2..]);
+    // least significant 12 bits of b
+    ubuf[6..8].copy_from_slice(&b12.to_be_bytes());
+    // least significant 62 bits of c
+    ubuf[8..16].copy_from_slice(&c62.to_be_bytes());
+
+    Ok(PyUuid::from(uuid::Uuid::new_v8(ubuf)))
 }
 
 // ----------------------------------------------------------------------------
@@ -546,8 +632,10 @@ fn py_uuid_type_ptr(py: Python) -> usize {
 // ``````
 
 // NEW VERSION THAT USES TYPE POINTER COMPARISON
-impl FromPyObject<'_> for CPythonUuid {
-    fn extract_bound(obj: &Bound<'_, PyAny>) -> PyResult<Self> {
+impl<'py> FromPyObject<'_, 'py> for CPythonUuid {
+    type Error = pyo3::PyErr;
+
+    fn extract(obj: Borrowed<'_, 'py, PyAny>) -> Result<Self, Self::Error> {
         let py = obj.py();
         let uuid_cls_ptr = py_uuid_type_ptr(obj.py());
         let obj_ptr = obj.get_type().as_type_ptr() as usize;
@@ -556,7 +644,7 @@ impl FromPyObject<'_> for CPythonUuid {
             let bytes = uuid_int.to_be_bytes();
             Ok(Self(uuid::Uuid::from_bytes(bytes)))
         } else {
-            Err(PyTypeError::new_err("Expected a `uuid.UUID` instance."))
+            py_type_err!("Expected a `uuid.UUID` instance.",)
         }
     }
 }
