@@ -42,6 +42,7 @@ from ry.ryo3 import (
     USIZE_MIN,
     AsyncFile,
     Bytes,
+    Certificate,
     Cookie,
     Date,
     DateDifference,
@@ -81,6 +82,7 @@ from ry.ryo3 import (
     SocketAddrV4,
     SocketAddrV6,
     SqlfmtQueryParams,
+    SqlFormatter,
     Time,
     TimeDifference,
     TimeRound,
@@ -124,6 +126,7 @@ from ry.ryo3 import (
     date,
     datetime,
     dirs,
+    exists,
     exists_async,
     fetch,
     fmt_size,
@@ -134,6 +137,7 @@ from ry.ryo3 import (
     gzip,
     gzip_decode,
     gzip_encode,
+    hard_link,
     hard_link_async,
     home,
     instant,
@@ -168,9 +172,11 @@ from ry.ryo3 import (
     read_dir,
     read_dir_async,
     read_json,
+    read_link,
     read_link_async,
     read_stream,
     read_text,
+    read_to_string,
     read_to_string_async,
     remove_dir,
     remove_dir_all,
@@ -180,6 +186,7 @@ from ry.ryo3 import (
     remove_file_async,
     rename,
     rename_async,
+    set_permissions,
     shouty_kebab_case,
     shouty_snake_case,
     shplit,
@@ -187,10 +194,12 @@ from ry.ryo3 import (
     sleep_async,
     snake_case,
     snek_case,
+    soft_link,
     sqlfmt,
     sqlfmt_params,
     stringify,
     stringify_unsafe,
+    symlink_metadata,
     time,
     timespan,
     title_case,
@@ -259,6 +268,7 @@ __all__ = (
     "USIZE_MIN",
     "AsyncFile",
     "Bytes",
+    "Certificate",
     "Cookie",
     "Date",
     "DateDifference",
@@ -297,6 +307,7 @@ __all__ = (
     "SocketAddr",
     "SocketAddrV4",
     "SocketAddrV6",
+    "SqlFormatter",
     "SqlfmtQueryParams",
     "Time",
     "TimeDifference",
@@ -341,6 +352,7 @@ __all__ = (
     "date",
     "datetime",
     "dirs",
+    "exists",
     "exists_async",
     "fetch",
     "fmt_size",
@@ -351,6 +363,7 @@ __all__ = (
     "gzip",
     "gzip_decode",
     "gzip_encode",
+    "hard_link",
     "hard_link_async",
     "home",
     "instant",
@@ -385,9 +398,11 @@ __all__ = (
     "read_dir",
     "read_dir_async",
     "read_json",
+    "read_link",
     "read_link_async",
     "read_stream",
     "read_text",
+    "read_to_string",
     "read_to_string_async",
     "remove_dir",
     "remove_dir_all",
@@ -398,6 +413,7 @@ __all__ = (
     "rename",
     "rename_async",
     "ryo3",
+    "set_permissions",
     "shouty_kebab_case",
     "shouty_snake_case",
     "shplit",
@@ -405,10 +421,12 @@ __all__ = (
     "sleep_async",
     "snake_case",
     "snek_case",
+    "soft_link",
     "sqlfmt",
     "sqlfmt_params",
     "stringify",
     "stringify_unsafe",
+    "symlink_metadata",
     "time",
     "timespan",
     "title_case",
