@@ -14,7 +14,7 @@ from ry.ryo3._dev import *  # noqa: F403
 __version__ = ryo3.__version__
 __build_profile__ = ryo3.__build_profile__
 __build_timestamp__ = ryo3.__build_timestamp__
-if hasattr(ryo3, "__all__"):
+if hasattr(ryo3, "__all__"):  # pragma: no cover
     __all__ = ryo3.__all__ + ryo3._dev.__all__  # type: ignore[attr-defined]
 
 # assign all things in ry03 to this module
