@@ -27,3 +27,13 @@ class TestDateUntil:
         earlier = ry.date(2006, 8, 24)
         later = ry.date(2019, 1, 31)
         assert later.until(earlier) == ry.timespan(days=-4543)
+
+
+class TestDateTomorrowYesterday:
+    def test_date_tomorrow(self) -> None:
+        d = ry.date(2023, 3, 14)
+        assert d.tomorrow() == ry.date(2023, 3, 15)
+
+    def test_date_yesterday(self) -> None:
+        d = ry.date(2023, 3, 14)
+        assert d.yesterday() == ry.date(2023, 3, 13)
